@@ -57,7 +57,8 @@ import parse_requirements
 from find_module import find_python_module
 from engage_django_components import COMPONENTS_FILENAME, read_components_file
 from package_data import PREINSTALLED_PACKAGES, get_apps_for_packages, \
-     PACKAGES_FOR_KNOWN_APPS
+     PACKAGES_FOR_KNOWN_APPS, validate_package_list
+
 
 
 SETTINGS_FILENAME = "settings.py"
@@ -287,6 +288,7 @@ def get_user_required_packages(app_dir_path):
     else:
         logger.debug("Did not find requirements.txt file")
         return []
+        
 
 def _get_subdir_component(parent_dir, subdir):
     """Given two paths, where the second is a subdirectory of the
@@ -382,10 +384,15 @@ def validate_settings(app_dir_path, django_settings_module, django_config=None,
                           settings_module.ADMIN_MEDIA_PREFIX,
                           results)
 
+    # Get the packages in requirements.txt. We use this in validating
+    # the django apps. We defer the validation of the actual packages
+    # until we have parsed and validated the engage_components.json file.
+    user_required_packages = get_user_required_packages(app_dir_path)
+    
     # check that all INSTALLED_APPS are pointing to apps accessible in the target system
     if hasattr(settings_module, "INSTALLED_APPS"):
         installed_apps = []
-        packages = PREINSTALLED_PACKAGES + get_user_required_packages(app_dir_path)
+        packages = PREINSTALLED_PACKAGES + user_required_packages
         known_apps = set(get_apps_for_packages(packages))
         for app_name in settings_module.INSTALLED_APPS:
             validate_installed_app(app_name, python_path_dir, known_apps,
@@ -433,7 +440,11 @@ def validate_settings(app_dir_path, django_settings_module, django_config=None,
             results.components = read_components_file(cf, additional_comp_file, None)
     else:
         results.components = []
-        
+
+    # validate the user required packages, taking into account the components requested
+    # by the user.
+    validate_package_list(user_required_packages, results.components, results)
+    
     # extract the product name and version, if present
     if hasattr(settings_module, "ENGAGE_PRODUCT_NAME"):
         results.product = settings_module.ENGAGE_PRODUCT_NAME
