@@ -3,6 +3,7 @@
 import sys
 import os.path
 import json
+import traceback
 
 try:
     from engage_django_sdk.version import VERSION
@@ -10,6 +11,8 @@ except ImportError:
     sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "../..")))
     from engage_django_sdk.version import VERSION
 
+from errors import ValidationError
+
 # Return codes
 SUCCESS_RC                   = 0
 SETTINGS_VALIDATION_ERROR_RC = 1
@@ -28,8 +31,11 @@ _rc_descriptions = {
 }
 
 class ResultsBase(object):
-    def __init__(self, version, error_messages=None, warning_messages=None,
-                 exception=None):
+    def __init__(self, version=VERSION, error_messages=None, warning_messages=None,
+                 exception=None, product=None, product_version=None,
+                 python_path_subdirectory=None, installed_apps=None,
+                 fixtures=None, migration_apps=None, components=None,
+                 post_install_commands=None):
         self.version = version
         if error_messages:
             self.error_messages = error_messages
@@ -40,9 +46,17 @@ class ResultsBase(object):
         else:
             self.warning_messages = []
         self.exception = exception
+        self.product = product
+        self.product_version = product_version
+        self.python_path_subdirectory = python_path_subdirectory
+        self.installed_apps = installed_apps
+        self.fixtures = fixtures
+        self.migration_apps = migration_apps
+        self.components = components
+        self.post_install_commands = post_install_commands
 
     def get_return_code(self):
-        pass
+        raise Exception("%s does not implement get_return_code()!" % self.__type__.__name__)
 
     def get_return_code_desc(self):
         if _rc_descriptions.has_key(self.get_return_code()):
@@ -56,20 +70,33 @@ class ResultsBase(object):
                u"return_code_desc": self.get_return_code_desc(),
                u"error_messages": self.error_messages,
                u"warning_messages": self.warning_messages,
-               u"exception": self.exception }
+               u"exception": self.exception,
+               u"product": self.product,
+               u"product_version": self.product_version,
+               u"python_path_subdirectory":self.python_path_subdirectory,
+               u"installed_apps": self.installed_apps,
+               u"fixtures": self.fixtures,
+               u"migration_apps":self.migration_apps,
+               u"components":self.components,
+               u"post_install_commands":self.post_install_commands}
         return js
 
 
-def create_results_json(rc, command, error_messages=[], warning_messages=[],
-                        exception=None):
-    js = { u"validator_version":VERSION,
-           u"return_code": rc,
-           u"return_code_desc": _rc_descriptions[rc],
-           u"error_messages": error_messages,
-           u"warning_messages": warning_messages,
-           u"exception": exception }
-    return js
+class FatalErrorResults(ResultsBase):
+    def __init__(self, return_code, exc_type, exc_value, exc_traceback):
+        if isinstance(exc_value, ValidationError):
+            msg = "%s: %s" % (exc_type.__name__, str(exc_value))
+        else:
+            msg = "Unexpected exception: %s(%s)" % (exc_type.__name__, str(exc_value))
+        ResultsBase.__init__(self, error_messages=[msg],
+                             exception=traceback.format_exception(exc_type,
+                                                                  exc_value,
+                                                                  exc_traceback))
+        self.return_code = return_code
 
+    def get_return_code(self):
+        return self.return_code
+                             
 
 class ParsedJsonResults(ResultsBase):
     """This object represents the results file after it has been
@@ -83,16 +110,31 @@ class ParsedJsonResults(ResultsBase):
                                 json_obj.__repr__())
             props = [u"return_code", u"return_code_desc",
                      u"validator_version", u"error_messages",
-                     u"warning_messages", u"exception"]
+                     u"warning_messages", u"exception",
+                     u"product", u"product_version",
+                     u"python_path_subdirectory",
+                     u"installed_apps",
+                     u"fixtures",
+                     u"migration_apps",
+                     u"components",
+                     u"post_install_commands"]
             for prop in props:
                 if not json_obj.has_key(prop):
                     raise Exception("Invalid results file, missing property %s" %
                                     prop)
             ResultsBase.__init__(self,
-                                 json_obj[u"validator_version"],
-                                 json_obj[u"error_messages"],
-                                 json_obj[u"warning_messages"],
-                                 json_obj[u"exception"])
+                                 version=json_obj[u"validator_version"],
+                                 error_messages=json_obj[u"error_messages"],
+                                 warning_messages=json_obj[u"warning_messages"],
+                                 exception=json_obj[u"exception"],
+                                 product=json_obj[u"product"],
+                                 product_version=json_obj[u"product_version"],
+                                 python_path_subdirectory=json_obj[u"python_path_subdirectory"],
+                                 installed_apps=json_obj[u"installed_apps"],
+                                 fixtures=json_obj[u"fixtures"],
+                                 migration_apps=json_obj[u"migration_apps"],
+                                 components=json_obj[u"components"],
+                                 post_install_commands=json_obj[u"post_install_commands"])
             self.return_code = json_obj[u"return_code"]
             self.return_code_desc = json_obj[u"return_code_desc"]
         except Exception, v:
@@ -124,6 +166,18 @@ class ParsedJsonResults(ResultsBase):
     def get_warning_messages(self):
         return self.warning_messages
 
+    def all_checks_passed(self):
+        return len(self.warning_messages)==0 and \
+               len(self.error_messages)==0
+    
+    def print_final_status_message(self, logger):
+        if self.all_checks_passed():
+            logger.info(">> All settings checks passed.")
+        else:
+            logger.error(">> %d errors, %d warnings in settings validation." %
+                         (len(self.error_messages),
+                          len(self.warning_messages)))
+
     def format_messages(self):
         s = ""
         if self.has_error_messages():
@@ -150,14 +204,6 @@ class SettingValidationResults(ResultsBase):
     def __init__(self, version, logger):
         ResultsBase.__init__(self, version)
         self.logger = logger
-        self.product = None
-        self.product_version = None
-        self.python_path_subdirectory = None
-        self.installed_apps = None
-        self.fixtures = None
-        self.migration_apps = None
-        self.components = None
-        self.post_install_commands = None
         self.errors = 0
         self.warnings = 0
 
@@ -182,9 +228,9 @@ class SettingValidationResults(ResultsBase):
 
     def print_final_status_message(self, logger):
         if self.all_checks_passed():
-            self.logger.info("All settings checks passed\n")
+            self.logger.info(">> All settings checks passed.")
         else:
-            self.logger.error("%d errors, %d warnings in settings validation.\n" %
+            self.logger.error(">> %d errors, %d warnings in settings validation." %
                               (self.errors, self.warnings))
         
     def get_return_code(self):
